[header]
<table align="center" border ="0" cellpadding ="2" cellspacing="10" summary="navigation" width="100%"><tr><td align="center"><a class="menuLink2" name ="pages">[pages/]</a>
[/header]
[links]
<a class="menuLink3" href="[href/]">[title/]</a>&#160;
[/links]
[currentLinks]
<a class="menuLink2" href="[href/]">[title/]</a>&#160;
[/currentLinks]
[previous]
<a class="menuLink2" href="[href/]"><img src="/style/Crystal/prev.png" alt="Previous" border="0" title="Previous" style="cursor:pointer;"/></a>
[/previous]
[next]
<a class="menuLink2" href="[href/]"><img src="/style/Crystal/next.png" alt="Next" border="0" title="Next" style="cursor:pointer;"/></a>
[/next]
[footer]
</td></tr></table>
[/footer]
