[menuHeader]
<table  align="center" border="0"  cellpadding="0" cellspacing="0" summary="layoutMenu" width="100%">
<tr>
<td valign="top">
<table align="center" border="0"  cellpadding="0" cellspacing="0" summary="layoutMenu" width="100%">
<tr>
<td  width="10" valign="bottom"><img src="/style/lze/tabwidget/linksOben1K.png" style="vertical-align:bottom;" width="10" height="10" alt="" border="0"/></td>
<td class="underline">
<table align="center" border="0" cellpadding="0" cellspacing="0" summary="layoutMenuLinks">
<tr>
[/menuHeader]
[link]
<td><table id="[id/]" border="0" cellpadding="0" cellspacing="0" summary="layoutMenuLink"><tr>
<td width="10" ><img src="/style/[style/]/tabwidget/mlU.png" alt="" id="image[id/]" title="[title/]" border="0" align="middle"/></td>
<td class="under" align="left" id="under1[id/]" >[text/]</td>
<td width="10" class="underR" id="under2[id/]" ></td>
</tr></table></td>
[/link]
[currentLink]
<td><table id="table[id/]" border="0" cellpadding="0" cellspacing="0" summary="layoutCurrentMenuLink"><tr>
<td width="10"><img src="/style/[style/]/tabwidget/mlO.png" alt="" title="[title/]" border="0" align="middle" id="image[id/]"/></td>
<td class="over" align="left" valign="middle" id="under1[id/]">[text/]</td>
<td width="10" class="overR" id="under2[id/]"></td>
</tr></table></td>
[/currentLink]
[menuFooter]
</tr>
</table>
</td>
<td  width="10" valign="bottom"><img src="/style/lze/tabwidget/rechtsOben1K.png" style="vertical-align:bottom;" width="10" height="10" alt="" border="0"/></td>
</tr>
<tr><td><img src="/style/lze/tabwidget/linksObenK.png" class="lorkg" width="10" height="10" alt="" border="0"/></td><td class="bodyTab" ></td><td valign="top" width="10" ><img src="/style/lze/tabwidget/rechtsObenK.png" class=""  alt="" width="10" height="10" hspace="0" vspace="0" border="0"/></td></tr>
</table>
[/menuFooter]
[bheader]
<table align="center" border="0" cellpadding="0" cellspacing="0" summary="" width="100%">
<tr>
<td width="2" class="linksTab"><img src="/style/lze/tabwidget/str.jpg" width="2" height="2" border="0" alt=""/></td>
<td align="left" valign="top"  class="tabwidgetBody">
[/bheader]
[bfooter]
</td>
<td class="rechtsk" width="2" ><img src="/style/lze/tabwidget/str.jpg" width="2" height="2" border="0" alt=""/></td>
</tr>
</table>
</td>
</tr>
<tr>
<td>
<table align="left" border="0" cellpadding="0" cellspacing="0" summary="" width="100%">
<tr>
<td >
<table  align="center" border="0" cellpadding="0" summary="" cellspacing="0"  width="100%">
<tr>
<td width="10" ><img src="/style/lze/tabwidget/linksUntenK.png" class="obrkg"  alt="" width="10" height="10" hspace="0" vspace="0" border="0"/></td>
<td class="horRibbon" valign="bottom"><img src="/style/lze/tabwidget/str.jpg" width="2" height="2" border="0" alt=""/></td>
</tr>
</table>
</td>
<td width="10" ><img src="/style/lze/tabwidget/rechtsUntenK.png" class="obrkg"  alt="" width="10" height="10" hspace="0" vspace="0" border="0"/></td>
</tr>
</table>
</td>
</tr>
</table>
<script language="JavaScript1.5" type="text/javascript">
/* <![CDATA[ */
function showTableMenu(id){
       hide('DatabaseMenu');
       hide('SqlEditor');
       hide('NewEntry');
       visible('TableMenu');
       SetCurrent(id);
}
function showDatabaseMenu(id){
       hide('TableMenu');
       hide('SqlEditor');
       hide('NewEntry');
       visible('DatabaseMenu');
       SetCurrent(id);
}
function showSqlEditor(id){
       hide('DatabaseMenu');
       hide('TableMenu');
       hide('NewEntry');
       visible('SqlEditor');
       SetCurrent(id);
}
function showNewEntry(){
       hide('DatabaseMenu');
       hide('SqlEditor');
       visible('TableMenu');
       displayTree('NewEntry');
}
function SetCurrent(id){
       if(document.getElementById("under1menuLink0")){
              document.getElementById("imagemenuLink0").src ="/style/lze/tabwidget/mlU.png";
              document.getElementById("under1menuLink0").className ="under";
              document.getElementById("under2menuLink0").className ="underR";
       }
       if(document.getElementById("under1menuLink1")){
       document.getElementById("imagemenuLink1").src ="/style/lze/tabwidget/mlU.png";
       document.getElementById("under1menuLink1").className ="under";
       document.getElementById("under2menuLink1").className ="underR";
       }
       if(document.getElementById("under1menuLink2")){
              document.getElementById("imagemenuLink2").src ="/style/lze/tabwidget/mlU.png";
              document.getElementById("under1menuLink2").className ="under";
              document.getElementById("under2menuLink2").className ="underR";
       }
       document.getElementById("image"+id).src ="/style/lze/tabwidget/mlO.png";
       document.getElementById("under1"+id).className ="over";
       document.getElementById("under2"+id).className ="overR";
}

/* ]]> */
</script>
<table id="menupopup" class="menupopup"  border="0" style="display:none;border-width:1px;border-style:solid;" cellpadding="0" cellspacing="0">
<tr>
<td align="left" style="border-width:0px;"><a onclick="location.href='[scriptName/]?action=EditFile&amp;name=[action/]'" class="menupoint">[tr=EditFile/]</a></td>
</tr>
<tr>
<td align="left" ><a onclick="location.href='[scriptName/]?action=EditAction&amp;name=[action/]'" class="menupoint">[tr=EditAction/]</a></td>
</tr>
<tr>
<td align="left" ><a onclick="location.href='[scriptName/]?action=EditTopMenu&amp;name=[action/]'" class="menupoint">[tr=EditVMenu/]</a></td>
</tr>
<tr>
<td align="left" ><a onclick="location.href='[scriptName/]?action=EditVertMenu&amp;name=[action/]'" class="menupoint">[tr=EditHMenu/]</a></td>
</tr>
</table>
[bfooter/]
[action]
<table align ="left" border ="0" cellpadding ="0" cellspacing="0" summary="layoutMenuItem"><tr><td valign="middle"><img onclick="location.href='[href/]'" src="/style/lze/buttons/[src/]" width="16" height="16" border="0" alt="" title="[title/]" style="font-size:14px;"/></td><td valign="middle"><a class="link" [onclick/]  style="font-size:16px;padding-left:2px;" title="[title/]" id="[id/]">[text/]</a></td></tr></table>
[/action]