$VAR1 = {
          'en' => {
                  'insert' => 'Insert',
                  'files' => 'Explorer',
                  'openfile' => 'Explorer',
                  'editmysqluserrights' => 'Database',
                  'save' => 'Save',
                  'rename' => 'Rename',
                  'email' => 'Email Adress',
                  'optionale email adresse' => 'Optionale email adresse',
                  'wrongusername' => 'Wrong Username',
                  'password' => 'Password',
                  'edittable' => 'Database',
                  'admincenter' => 'Admin',
                  'logout' => 'Logout',
                  'category' => 'Category',
                  'endtable' => 'at end',
                  'newmenu' => 'Create new Menu',
                  'multipleaction' => 'Database',
                  'name' => 'Name',
                  'details' => 'Details',
                  'movetreeviewentry' => 'TreeView',
                  'dumpdatabase' => 'Database',
                  'properties' => 'Properties',
                  'importfirefox' => 'Import FireFox Bookmarks',
                  'trash' => 'Trash',
                  'unselect_all' => 'Select none',
                  'translate' => 'Translate',
                  'showrights' => 'Show rights',
                  'delete' => 'Delete',
                  'chars' => 'Chars left:',
                  'editvmenu' => 'Edit V-Menu',
                  'links_pro_page' => 'links/page',
                  'non_unique' => 'Non_unique',
                  'saveedittable' => 'Database',
                  'mailsendet' => '<div align="center">Sie haben eine email mit Ihren Passwort zugesendet bekommen.<br/></div>',
                  'showfiles' => 'Explorer',
                  'deletefile' => 'Explorer',
                  'insertafter' => 'After',
                  'changecurrentdb' => 'Change Database User',
                  'cardinality' => 'Cardinality',
                  'createnewtable' => 'Database',
                  'pass' => 'Password',
                  'showdatabases' => 'Databases',
                  'edithmenu' => 'Edit H-Menu',
                  'truncate' => 'Truncate',
                  'showeditindex' => 'Database',
                  'editnavi' => 'Edit Navigation',
                  'edittableprops' => 'Database',
                  'sort' => 'Sort',
                  'fields' => 'Fields',
                  'select_all' => 'Select All',
                  'index_type' => 'Index_type',
                  'profile' => 'Profile',
                  'next' => 'Next',
                  'feeds' => 'Rss Feeds',
                  'importoperabookmarks' => 'Bookmarks',
                  'upentry' => 'Sort',
                  'comments' => 'Comments',
                  'exportdatabase' => 'Database',
                  'newentry' => 'New Entry',
                  'createdatabase' => 'New Database',
                  'editaction' => 'Edit Action',
                  'nachricht' => 'nachricht',
                  'chmodfile' => 'Explorer',
                  'makedir' => 'Explorer',
                  'user' => 'user',
                  'lostpass' => 'Lost Password',
                  'savefile' => 'Explorer',
                  'export' => 'Export',
                  'newfolder' => 'Append',
                  'haveacount' => 'You already have an Acount',
                  'links' => 'Sitemap',
                  'savetreeviewentry' => 'TreeView',
                  'newindex' => 'New Index',
                  'admin' => 'Admin',
                  'addtreeviewentry' => 'Add new entry',
                  'failed: invalid code' => 'failed: invalid code',
                  'newdir' => 'Explorer',
                  'createuser' => 'Create User',
                  'editentry' => 'Edit Entry',
                  'saverights' => 'Database',
                  'getpass' => 'Lost Password',
                  'null' => 'Null',
                  'retry' => 'retry',
                  'exportoperabookmarks' => 'Bookmarks',
                  'multipledbaction' => 'Database',
                  'preview' => 'Preview',
                  'bookmarks' => 'Bookmarks',
                  'type' => 'type',
                  'repairtable' => 'Database',
                  'fileopen' => 'fileopen',
                  'newpass' => 'New Password',
                  'rows in effect' => 'rows in effect',
                  'dropdatabase' => 'Drop Database',
                  'after' => 'after',
                  'city' => 'City',
                  'column_name' => 'Column_name',
                  'showtables' => 'Show Tables',
                  'analyzetable' => 'Analyze Table',
                  'newmessagereleased' => 'New Message saved',
                  'familyname' => 'Family Name',
                  'auswahl aufheben' => 'Auswahl aufheben',
                  't_regtext' => 'Register',
                  'back' => 'Back',
                  'datenbank' => 'datenbank',
                  'readmore' => 'Read More',
                  'phone' => 'Phone Number',
                  'createindex' => 'Database',
                  'showtabledetails' => 'Show Table Details',
                  'host' => 'host',
                  'navigation' => 'Navigation',
                  'register' => 'Register',
                  'mailsubject' => 'Register',
                  'permission denied' => 'permission denied',
                  'indexover' => 'Indexover',
                  'optimize' => 'Optimize',
                  'execsql' => 'Exec Sql',
                  'news' => 'Logbook',
                  'importfirefoxbookmarks' => 'importfirefoxbookmarks',
                  'headline' => 'Headline',
                  'rights' => 'Rights',
                  'edit entry' => 'Edit Entry',
                  'table' => 'Table',
                  'drop_database' => 'drop_database',
                  'caption' => 'Caption',
                  'dragsharelink' => 'Drag link to your Bookmarks',
                  'regmessage' => 'You receive this email from Lindnerei.de',
                  'folderfirst' => 'Folder first',
                  'sql' => 'SQL',
                  'newfile' => 'Explorer',
                  'createtable' => 'Create Table',
                  'saveentry' => 'Save Entry',
                  'edittree' => 'Edit',
                  'username' => 'User',
                  'catslist' => 'catslist',
                  'showusers' => 'Show Users',
                  'deletetreeviewentry' => 'Delete',
                  'explorer' => 'Explorer',
                  'showtable' => 'Show Table',
                  'changeautoincrementvalue' => 'Database',
                  'news_pro_page' => 'News pro page',
                  'optimizetable' => 'Optimize Table',
                  'welcome' => 'Welcome',
                  'packed' => 'Packed',
                  'newpost' => 'New Message',
                  'edit' => 'Edit',
                  'size' => 'Size',
                  'body' => 'Body',
                  'summary' => 'Summary',
                  'edittreeviewentry' => 'Editor',
                  'editfile' => 'Editor',
                  'newfileadded' => 'New File created',
                  'referer' => 'Referer',
                  'create' => 'Create',
                  'choosefile' => 'Choose Attachment',
                  'edit links' => 'Edit Sitemap',
                  'shownewentry' => 'New Entry',
                  'deleteentry' => 'Delete Entry',
                  'env' => 'Env',
                  'repair' => 'Repair',
                  'key_name' => 'Key_name',
                  'database' => 'Database',
                  'reg' => 'Register',
                  'inserttext' => 'Insert Text',
                  'firstname' => 'Firstname',
                  'search' => 'Search',
                  'done' => 'Done',
                  'street' => 'Street',
                  'insertpass' => 'Insert Password',
                  'edit table' => 'Edit Table',
                  'about' => 'About',
                  'floodtext' => 'To many Posts',
                  'answers' => 'Answers',
                  'field' => 'field',
                  'show' => 'Show',
                  'sites' => 'Sites',
                  'truncatetable' => 'Truncate',
                  'nomail' => 'No Email Adress given.',
                  'newcol' => 'New Column',
                  'insertname' => 'Insert Your Name',
                  'fileexists' => 'File already Exists',
                  'newtreeviewentry' => 'New Entry',
                  'downentry' => 'Sort',
                  'buildfeeds' => 'Rss Feeds',
                  'kontaktsubjects' => 'kontaktsubjects',
                  'edittreeview' => 'Edit',
                  'newtable' => 'New Table',
                  'userexits' => 'This name is already in use.<br/>',
                  'wrongpass' => 'Wrong Password',
                  'starttable' => 'at start',
                  'impressum' => 'Impressum',
                  'sub_part' => 'sub_part',
                  'gbook_body' => 'Write your entry',
                  'sharelink' => 'Share',
                  'mysqldump' => 'Mysql dump',
                  'realy' => 'Realy',
                  'help' => 'Help',
                  'editmessage' => 'Edit',
                  'postcode' => 'Postcode',
                  'gbook' => 'Gbook',
                  'connect' => 'Connect',
                  'dumptable' => 'Databases',
                  'databases' => 'Databases',
                  'blog' => 'Logbook',
                  'settings' => 'Settings',
                  'seq_in_index' => 'Seq_in_index',
                  'reply' => 'Replies',
                  'comment' => 'Comment',
                  'action' => 'Action',
                  'selected' => 'Select all',
                  'newmessage' => 'New Topic',
                  'showwindow' => 'Show Windows',
                  'changeengine' => 'Change Engine'
                },
          'de' => {
                  'insert' => 'Einf&#252;gen',
                  'openfile' => 'Explorer',
                  'files' => 'Explorer',
                  'editmysqluserrights' => 'Datenbank',
                  'save' => 'Speichern',
                  'rename' => 'Umbenennen',
                  'email' => 'Email Adresse',
                  'password' => 'Passwort',
                  'wrongusername' => 'Sie haben keinen oder einen ung&#252;ltigen usernamen eingegeben, bitte eingabe wiederhohlen.<br/>',
                  'optionale email adresse' => 'optionale email adresse',
                  'edittable' => 'Database',
                  'admincenter' => 'Admin',
                  'logout' => 'Abmelden',
                  'endtable' => 'am ende',
                  'category' => 'Kategorie',
                  'dein name' => 'Dein name',
                  'newmenu' => 'Neues Menu erstellen',
                  'multipleaction' => 'Datenbank',
                  'name' => 'Name',
                  'movetreeviewentry' => 'TreeView',
                  'details' => 'Details',
                  'properties' => 'Einstellungen',
                  'dumpdatabase' => 'Datenbank',
                  'importfirefox' => 'Firefox Lesezeichen importieren',
                  'nachricht senden' => 'Nachricht senden',
                  'trash' => 'M&#252;lleimer',
                  'unselect_all' => 'Auswahl aufheben',
                  'translate' => '&#220;bersetzen',
                  'showrights' => 'Datenbank',
                  'editvmenu' => 'Vertikales Menu',
                  'delete' => 'L&#246;schen',
                  'chars' => 'Zeichen &#252;brig:',
                  'sitemap' => '&#252;bersicht',
                  'links_pro_page' => 'Eintr&#228;ge/Seite',
                  'non_unique' => 'Nicht Unique',
                  'saveedittable' => 'Datenbank',
                  'mailsendet' => '<div align="center">Sie haben eine email mit Ihren Passwort zugesendet bekommen.<br/></div>',
                  'showfiles' => 'Explorer',
                  'deletefile' => 'Explorer',
                  'insertafter' => 'Einf&#252;gen',
                  'changecurrentdb' => 'Benutzer wechseln',
                  'cardinality' => 'Kardinalit&#228;t',
                  'createnewtable' => 'Neue Tabelle erstellen',
                  'speichern' => 'Speichern',
                  'pass' => 'Passwort',
                  'showdatabases' => 'Datenbanken',
                  'truncate' => 'Leeren',
                  'showeditindex' => 'Datenbank',
                  'edithmenu' => 'Horizontales Menu',
                  'editnavi' => 'Navigation',
                  'sort' => 'Sortieren',
                  'edittableprops' => 'Bearbeiten',
                  'fields' => 'Spalten',
                  'select_all' => 'Alle ausw&#228;hlen',
                  'index_type' => 'Type',
                  'profile' => 'Einstellungen',
                  'next' => 'Weiter',
                  'importoperabookmarks' => 'Opera Lezeichen importieren',
                  'feeds' => 'Rss',
                  'upentry' => 'TreeView',
                  'exportdatabase' => 'Datenbank',
                  'comments' => 'Kommentare',
                  'newentry' => 'Neuer Eintrag',
                  'editaction' => 'Aktion bearbeiten',
                  'createdatabase' => 'Neue Datenbank',
                  'chmodfile' => 'Explorer',
                  'nachricht' => 'nachricht',
                  'makedir' => 'Explorer',
                  'user' => 'user',
                  'lostpass' => 'Passwort vergessen',
                  'savefile' => 'Speichern',
                  'export' => 'Exportieren',
                  'newfolder' => 'Anh&#228;ngen',
                  'haveacount' => 'Sie haben bereits einen Acount',
                  'savetreeviewentry' => 'TreeView',
                  'links' => 'Sitemap',
                  'newindex' => 'Neuer Index',
                  'failed: invalid code' => 'Fehler: falscher Captcha Code',
                  'admin' => 'Administrator',
                  'addtreeviewentry' => 'Hinzuf&#252;gen',
                  'newdir' => 'Explorer',
                  'createuser' => 'Benutzer erstellen',
                  'editentry' => 'Eintrag bearbeiten',
                  'saverights' => 'Datenbank',
                  'getpass' => 'Passwort vergessen',
                  'null' => 'Null',
                  'retry' => 'Wiederholen',
                  'exportoperabookmarks' => 'Opera Lesezeichen exportieren',
                  'multipledbaction' => 'Datenbank',
                  'preview' => 'Vorschau',
                  'bookmarks' => 'Lesezeichen',
                  'type' => 'type',
                  'repairtable' => 'Reparieren',
                  'fileopen' => 'fileopen',
                  'newpass' => 'Neues Passwort',
                  'rows in effect' => 'rows in effect',
                  'dropdatabase' => 'Datenbank löschen',
                  'after' => 'nach',
                  'city' => 'Stadt',
                  'column_name' => 'Spalten Name',
                  'showtables' => 'Anzeigen',
                  'analyzetable' => 'Analysieren',
                  'newmessagereleased' => 'Nachricht wurde gespeichert',
                  'familyname' => 'Nachname',
                  'auswahl aufheben' => 'Auswahl aufheben',
                  't_regtext' => 'Registrieren',
                  'back' => 'zur&#252;ck',
                  'datenbank' => 'Datenbank',
                  'readmore' => 'ganzen Atikel lesen',
                  'phone' => 'Telefonnummer',
                  'showtabledetails' => 'Details',
                  'createindex' => 'Index erstellen',
                  'host' => 'host',
                  'register' => 'Registrieren',
                  'navigation' => 'Navigation',
                  'mailsubject' => 'Registrierung',
                  'permission denied' => 'Keine Berechtigung',
                  'indexover' => 'Index &#252;ber',
                  'optimize' => 'Optimieren',
                  'news' => 'Logbook',
                  'execsql' => 'Sql ausf&#252;hren',
                  'importfirefoxbookmarks' => 'importfirefoxbookmarks',
                  'headline' => '&#220;berschrift',
                  'rights' => 'Rechte',
                  'edit entry' => 'Eintrag Bearbeiten',
                  'table' => 'Tabelle',
                  'caption' => '&#220;berschrift',
                  'drop_database' => 'drop_database',
                  'regmessage' => 'Sie ehalten diese Email weil versucht wurde sich auf damit bei uns zu registrieren \\nWenn Sie diese Mail nicht angefordert haben bitte ich um entschuldigung.\\nAnsonsten lautet ihr \\n',
                  'dragsharelink' => 'Ins lesezeichen Menu ziehen',
                  'kontakt' => 'Kontakt',
                  'sql' => 'SQL',
                  'newfile' => 'Explorer',
                  'folderfirst' => 'Verzeichnisse zuerst',
                  'lang' => 'de',
                  'createtable' => 'Tabelle erstellen',
                  'saveentry' => 'Eintrag speichern',
                  'edittree' => 'Bearbeiten',
                  'username' => 'Benutzer',
                  'catslist' => 'catslist',
                  'deletetreeviewentry' => 'Lösche',
                  'showusers' => 'Benutzer Anzeigen',
                  'changeautoincrementvalue' => 'autoincrement wert &#228;ndern',
                  'showtable' => 'Tabelle Anzeigen',
                  'explorer' => 'Explorer',
                  'news_pro_page' => 'Nachrichten/Seite',
                  'optimizetable' => 'Optimieren',
                  'welcome' => 'Willkommen',
                  'packed' => 'Gepackt',
                  'newpost' => 'Neue Nachricht',
                  'edit' => 'Bearbeiten',
                  'size' => 'Gr&ouml;&szlig;e',
                  'body' => 'Text',
                  'summary' => 'Zusammenfassung',
                  'edittreeviewentry' => 'Bearbeiten',
                  'editfile' => 'Datei bearbeiten',
                  'newfileadded' => 'Neue Datei wurde erstellt',
                  'referer' => 'Referer',
                  'edit links' => 'Sitemap bearbeiten',
                  'create' => 'Erstellen',
                  'choosefile' => 'File ausw&#228;hlen',
                  'shownewentry' => 'Neuer Eintrag',
                  'deleteentry' => 'Eintrag l&#246;schen',
                  'env' => 'Variablen',
                  'repair' => 'Reparieren',
                  'key_name' => 'Schl&#252;ssel',
                  'database' => 'Datenbank',
                  'reg' => 'Registrieren',
                  'inserttext' => 'Text einf&#252;gen',
                  'firstname' => 'Vorname',
                  'search' => 'Suchen',
                  'done' => 'Gespeichert',
                  'street' => 'Strasse',
                  'insertpass' => 'Passwort eingeben',
                  'edit table' => 'Bearbeiten',
                  'about' => '&#220;ber',
                  'floodtext' => 'Nicht so oft posten',
                  'field' => 'field',
                  'answers' => 'Antworten',
                  'sites' => 'Seiten',
                  'show' => 'Anzeigen',
                  'truncatetable' => 'truncatetable',
                  'nomail' => 'Sie haben keine email adresse angegeben.',
                  'newcol' => 'Neue Zeile',
                  'insertname' => 'Namen eingeben',
                  'fileexists' => 'Datei existiert bereits',
                  'newtreeviewentry' => 'Neuer Eintrag',
                  'downentry' => 'TreeView',
                  'buildfeeds' => 'Rss',
                  'userexits' => 'Dieser Benutzer exestiert bereits bitte einen anderen Namen ausw&#228;hlen<br/>',
                  'newtable' => 'Neue Tabelle',
                  'edittreeview' => 'Bearbeiten',
                  'wrongpass' => 'Falsches Passwort',
                  'starttable' => 'am Anfang',
                  'daten' => 'Daten',
                  'alle markieren' => 'Alle markieren',
                  'sub_part' => 'Sub Part',
                  'impressum' => 'Impressum',
                  'gbook_body' => 'Text einf&#252;gen',
                  'sharelink' => 'Teilen',
                  'mysqldump' => 'Mysql dump',
                  'realy' => 'Wirklich',
                  'help' => 'Hilfe',
                  'postcode' => 'Postleitzahl',
                  'editmessage' => 'Bearbeiten',
                  'gbook' => 'G&#228;stebuch',
                  'connect' => 'Verbinden',
                  'dumptable' => 'Tabelle exportieren',
                  'databases' => 'Datenbanken',
                  'blog' => 'Weblog',
                  'settings' => 'Settings',
                  'seq_in_index' => 'seq_in_index',
                  'reply' => 'Antworten',
                  'shownewtable' => 'Neue Tabelle',
                  'comment' => 'Kommentar',
                  'action' => 'action',
                  'selected' => 'Alle ausw&#228;hlen',
                  'showwindow' => 'Fenster anzeigen',
                  'newmessage' => 'Neue Nachricht',
                  'changeengine' => 'Engine &#228;ndern'
                },
          'es' => {
                    'insert' => 'Insertar',
                    'files' => 'Explorer',
                    'openfile' => 'Explorer',
                    'editmysqluserrights' => 'Editar los permisos de los usuarios',
                    'save' => 'Guardar',
                    'rename' => 'Renombrar',
                    'email' => 'Email',
                    'optionale email adresse' => 'Direcci&#243;n de correo opcional',
                    'wrongusername' => 'Usuario incorrecto',
                    'password' => 'Clave',
                    'edittable' => 'Editar tabla',
                    'admincenter' => 'Admininistraci&#243;n',
                    'logout' => 'Desconectar',
                    'category' => 'Categor&#237;a',
                    'endtable' => 'al final',
                    'newmenu' => 'Crear nuevo Men&#250;',
                    'multipleaction' => 'Varias acciones',
                    'name' => 'Nombre',
                    'details' => 'Detalles',
                    'movetreeviewentry' => 'TreeView',
                    'dumpdatabase' => 'Borrar Base de datos',
                    'properties' => 'Propiedades',
                    'importfirefox' => 'Importar marcadores de FireFox',
                    'trash' => 'Basura',
                    'unselect_all' => 'No seleccionar nada',
                    'translate' => 'Trasladar',
                    'showrights' => 'Mostrar derechos',
                    'delete' => 'Borrar',
                    'chars' => 'Caracteres a la izquierda:',
                    'editvmenu' => 'Editar Men&#250; vertical',
                    'links_pro_page' => 'enlaces/p&#225;gina',
                    'non_unique' => 'No_unicos',
                    'saveedittable' => 'Guardar tabla',
                    'mailsendet' => '<div align="center">Se le ha enviado un correo con su contrase&#241;a.<br/></div>',
                    'showfiles' => 'Mostrar archivos',
                    'deletefile' => 'Borrar archivo',
                    'insertafter' => 'Despu&#233;s',
                    'changecurrentdb' => 'Cambiar el usuario de la Base de datos',
                    'cardinality' => 'Cardinalidad',
                    'createnewtable' => 'Crear nueva tabla',
                    'pass' => 'Clave',
                    'showdatabases' => 'Bases de datos',
                    'edithmenu' => 'Editar Men&#250; horizontal',
                    'truncate' => 'Truncar',
                    'showeditindex' => 'Mostrar &#237;ndice',
                    'editnavi' => 'Editar navegaci&#243;n',
                    'edittableprops' => 'Database',
                    'sort' => 'Ordenar',
                    'fields' => 'Campos',
                    'select_all' => 'Seleccionar Todo',
                    'index_type' => 'Tipo &#237;ndice',
                    'profile' => 'Perfil',
                    'next' => 'Siguiente',
                    'feeds' => 'Rss',
                    'importoperabookmarks' => 'Importar marcadores de Opera',
                    'upentry' => 'Ordenar',
                    'comments' => 'Comentarios',
                    'exportdatabase' => 'Exportar',
                    'newentry' => 'Nueva entrada',
                    'createdatabase' => 'Nueva base de datos',
                    'editaction' => 'Acci&#243;n Editar',
                    'nachricht' => 'mensaje',
                    'chmodfile' => 'Explorer',
                    'makedir' => 'Explorer',
                    'lostpass' => 'Clave perdida',
                    'savefile' => 'Explorer',
                    'export' => 'Export',
                    'newfolder' => 'A&#241;dir',
                    'haveacount' => 'Ya tiene una cuenta',
                    'links' => 'Mapa del sitio',
                    'savetreeviewentry' => 'TreeView',
                    'newindex' => 'Nuevo &#205;ndice',
                    'admin' => 'Administraci&#243;n',
                    'addtreeviewentry' => 'A&#241;adir nueva entrada',
                    'failed: invalid code' => 'fallo: c&oacute:digo no v&aacute;lido',
                    'newdir' => 'Explorer',
                    'createuser' => 'Crear Usuario',
                    'editentry' => 'Editar entrada',
                    'saverights' => 'Base de datos',
                    'getpass' => 'Clave Perdida',
                    'null' => 'Null',
                    'retry' => 'reintentar',
                    'exportoperabookmarks' => 'Marcadores',
                    'multipledbaction' => 'Base de datos',
                    'preview' => 'Vista previa',
                    'bookmarks' => 'Marcadores',
                    'type' => 'tipo',
                    'repairtable' => 'Reparar tabla',
                    'newpass' => 'Nueva clave',
                    'rows in effect' => 'filas afectadas',
                    'dropdatabase' => 'Borrar base de datos',
                    'after' => 'despu&#233;s',
                    'city' => 'Ciudad',
                    'column_name' => 'Nombre Columna',
                    'showtables' => 'Mostrar tablas',
                    'analyzetable' => 'Analizar tablas',
                    'familyname' => 'Apellidos',
                    'auswahl aufheben' => 'Borrar selecci&#243;n',
                    't_regtext' => 'Registrar',
                    'back' => 'Volver',
                    'datenbank' => 'Base de datos',
                    'readmore' => 'Leer m&#225;s',
                    'phone' => 'N&uacute;mero de tel&eacute;fono',
                    'createindex' => 'Base de datos',
                    'showtabledetails' => 'Mostrar detalles de tabla',
                    'navigation' => 'Navegaci&#243;n',
                    'register' => 'Registrar',
                    'mailsubject' => 'Asunto',
                    'permission denied' => 'permiso denegado',
                    'indexover' => 'Indexover',
                    'optimize' => 'Optimizar',
                    'execsql' => 'Ejecutar Sql',
                    'news' => 'Registros',
                    'headline' => 'Cabecera',
                    'rights' => 'Permisos',
                    'edit entry' => 'Editar entrada',
                    'table' => 'Tabla',
                    'caption' => 'T&#237;tulo',
                    'dragsharelink' => 'Arrastre el enlace a sus marcadores',
                    'regmessage' => 'Ha recibido este correo desde Lindnerei.de',
                    'newfile' => 'Explorer',
                    'folderfirst' => 'Carpetas primero',
                    'sql' => 'SQL',
                    'createtable' => 'Crear tabla',
                    'saveentry' => 'Guardar entrada',
                    'edittree' => 'Editar',
                    'username' => 'Usuario',
                    'showusers' => 'Mostrar usuarios',
                    'deletetreeviewentry' => 'Borrar',
                    'explorer' => 'Explorer',
                    'showtable' => 'Mostrar tablas',
                    'changeautoincrementvalue' => 'Base de datos',
                    'news_pro_page' => 'Noticias',
                    'optimizetable' => 'Optimizar tabla',
                    'welcome' => 'Bienvenido',
                    'packed' => 'Comprimido',
                    'newpost' => 'Nuevo mensaje',
                    'edit' => 'Editar',
                    'size' => 'Tama&#241;o',
                    'body' => 'Cuerpo',
                    'summary' => 'Sumario',
                    'edittreeviewentry' => 'Editor',
                    'editfile' => 'Editor',
                    'newfileadded' => 'Nuevo archivo creado',
                    'referer' => 'Referer',
                    'create' => 'Crear',
                    'choosefile' => 'Elegir anexo',
                    'edit links' => 'Editar enlaces',
                    'shownewentry' => 'Nueva entrada',
                    'deleteentry' => 'Borrar entrada',
                    'env' => 'Env',
                    'repair' => 'Reparar',
                    'key_name' => 'Nombre clave',
                    'database' => 'Base de datos',
                    'reg' => 'Registrar',
                    'inserttext' => 'Insertar texto',
                    'firstname' => 'Nombre',
                    'search' => 'Buscar',
                    'done' => 'Hecho',
                    'street' => 'Calle',
                    'insertpass' => 'Insertar clave',
                    'edit table' => 'Editar tabla',
                    'about' => 'Acerca de',
                    'floodtext' => 'Demasiadas entradas',
                    'answers' => 'Respuestas',
                    'field' => 'campo',
                    'show' => 'Mostrar',
                    'sites' => 'Sitios',
                    'truncatetable' => 'Truncar',
                    'nomail' => 'No se ha especificado ninguna direcci&#243;n de email.',
                    'newcol' => 'Nueva columna',
                    'insertname' => 'Inserte su nombre',
                    'fileexists' => 'El archivo ya existe',
                    'newtreeviewentry' => 'Nueva entrada',
                    'downentry' => 'Ordenar',
                    'buildfeeds' => 'Rss',
                    'kontaktsubjects' => 'kontaktsubjects',
                    'edittreeview' => 'Editar',
                    'newtable' => 'Nueva tabla',
                    'userexits' => 'Ese nombre ya est&#225; en uso.<br/>',
                    'wrongpass' => 'Contrase&#241;a incorrecta',
                    'starttable' => 'al principio',
                    'impressum' => 'Impreso',
                    'sub_part' => 'sub_part',
                    'gbook_body' => 'Insertar texto',
                    'sharelink' => 'Compartir',
                    'mysqldump' => 'Mysql dump',
                    'realy' => 'Realmente',
                    'help' => 'Ayuda',
                    'editmessage' => 'Editar',
                    'postcode' => 'C&#243;digo postal',
                    'gbook' => 'Gbook',
                    'connect' => 'Conectar',
                    'dumptable' => 'Bases de datos',
                    'databases' => 'Bases de datos',
                    'blog' => 'Logbook',
                    'settings' => 'Configuraci&#243;n',
                    'seq_in_index' => 'Seq_in_index',
                    'reply' => 'Responder',
                    'comment' => 'Comentario',
                    'action' => 'Acci&#243;n',
                    'selected' => 'Seleccionar todo',
                    'newmessage' => 'Nuevo tema',
                    'showwindow' => 'Mostrar ventanas',
                    'changeengine' => 'Cambiar motor'
                  }
        };
$lang =$VAR1;