[bodyHeader]<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
<head>
<title>[title/]</title>
<meta name="description" content="MySql-Admin"/>
<meta name="author" content="Dirk Lindner"/>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>
<meta name="robots" content="index"/>
<meta name="revisit-after" content="1 days"/>
<link rel="alternate" type="application/rss+xml"  href="/news.rss"  title="News" />
<link href="/style/lze/lze[size/].css" rel="stylesheet" type="text/css"/>
<link href="/style/lze/tabwidget.css" rel="stylesheet" type="text/css"/>
<link href="/style/lze/window.css" rel="stylesheet" type="text/css"/>
<link href="/style/lze/pages.css" rel="stylesheet" type="text/css"/>
<link href="/style/lze/editor.css" rel="stylesheet" type="text/css"/>
<link href="/style/lze/[size/]/html-menu-treeview/lze.css" rel="stylesheet" type="text/css"/>
<script language="JavaScript1.5"  type="text/javascript" src="/javascript/tabwidget.js"></script>
<script language="JavaScript1.5"  type="text/javascript" src="/javascript/window.js"></script>
<script language="JavaScript1.5"  type="text/javascript" src="/javascript/editor.js"></script>
<script language="JavaScript1.5"  type="text/javascript" src="/style/lze/preload.js"></script>
<script language="JavaScript1.5"  type="text/javascript" src="/style/treeview.js"></script>
<script type="text/javascript">
 /* <![CDATA[ */
var style ="lze";
var right = [right/];
var htmlright = [htmlright/];
var size     = [size/];
var fontSize = [size/]
 /* ]]> */
</script>
<script language="JavaScript1.5"  type="text/javascript" src="/javascript/content.js"></script>
</head>
<body onclick="if(shown )hide('menupopup');" onload="restoreStatus()">
<table align="left"  border="0" cellpadding="0" cellspacing="0"  width="100%" summary="contentHeader">
<tr><td align="right">
<table align="left" border="0" cellpadding="2" cellspacing="0" style="vertical-align:middle;" width="100%" summary="contentHeader"><tr><td>[login/]</td><td  align="right">
<form action="[server/]" name="search" accept-charset="UTF-8" >
<table align="right" border="0" cellpadding="0" cellspacing="2" style="vertical-align:middle;" width="*" summary="contentHeader"><tr><td>
<input align="right" type="text" maxlength="100" title="[tr=search/]" value="[query/]" name="query" id="query" style="vertical-align:middle;height:16px;"/>
<input  type="hidden" name="action"  value="fulltext"/>
</td><td><input style="vertical-align:middle;height:18px;" type="submit"  name="submit" value="[tr=search/]"  alt="" align="right" />
</td></tr>
</table>
</form>
</td><td align="right" width="22" style="padding-left:2px;">[zoom/]</td></tr></table>
</td></tr>
<tr><td>
[bodyFooter]
</td></tr>
</table>
</body></html>
