my %parameter = ( path   => $m_hrSettings->{cgi}{bin} . '/templates',
                  style  => $m_sStyle,
                  title  => "",
                  server => $m_hrSettings->{serverName},
                  id     => 'exploit',
                  class  => 'min',
);
my $window = new HTML::Window( \%parameter );
$window->set_closeable(0);
$window->set_moveable(0);
$window->set_resizeable(1);
$m_sContent .= br();
$m_sContent .= $window->windowHeader();
my $remote_addr      = CGI::remote_addr()  ? CGI::remote_addr()  : 'none';
my $m_hrQuery_string = CGI::query_string() ? CGI::query_string() : 'none';
my $referer          = CGI::referer()      ? CGI::referer()      : 'none';
$m_sContent .=
      translate("Permission denied")
    . br()
    . "remote_addr: $remote_addr"
    . br()
    . "query_string: $m_hrQuery_string"
    . br()
    . "referer: $referer"
    . br();
$m_oDatabase->void(
       "INSERT INTO exploit(referer,remote_addr,query_string) VALUES (?,?,?)",
       $referer, $remote_addr, $m_hrQuery_string );
$m_sContent .= $@ if $@;
$m_sContent .= $window->windowFooter();
