td.underL{
background-image:url('/style/Crystal/tabwidget/mlU.png');
background-repeat:no-repeat;
height:24px;
}
td.under{
background-image:url('/style/Crystal/tabwidget/mmU.png');
background-repeat:repeat-x;
height:24px;
}
td.underline{
background-image:url('/style/Crystal/tabwidget/mul.png');
background-repeat:repeat-x;
}
td.underR{
background-image:url('/style/Crystal/tabwidget/mrU.png');
background-repeat:no-repeat;
height:24px;
}
 td.over{
background-image:url('/style/Crystal/tabwidget/mmO.png');
height:25px;
background-repeat:repeat-x;
}
td.overL{
background-image:url('/style/Crystal/tabwidget/mlO.png');
background-repeat:no-repeat;
height:25px;
}
td.overR{
background-image:url('/style/Crystal/tabwidget/mrO.png');
background-repeat:no-repeat;
height:25px;
}
td.line{
background-image:url('/style/Crystal/tabwidget/mul.png');
}
td.tabwidgetBody{
background-color:#ffffff;
}