$VAR1 = { 'start' => { 'file'  => 'start.pl',
                       'sub'   => 'main',
                       'right' => '',
                       'name'  => 'Lindner',
          },
};
$m_sActions = $VAR1;
