[windowheader]
<br/>
<table align="center" border="0" id="window[id/]" [hidden/] cellpadding="0" cellspacing="0" summary="thread"  class="[class/]">
<tr align="left" id="tr[id/]" [hidden/] ><td align="left" width="5"><img alt="" src="/style/[style/]/window/wlobgk.png" width="5" eight="1"  border="0"/></td>
<td align="left" style="background-image:url('/style/[style/]/window/wdcobgk.png'); background-repeat:repeat-x;"></td>
<td width="5"><img src="/style/[style/]/window/wrobgk.png" alt="" width="5"  height="1"  border="0" /></td>
</tr>
<tr align="left"  id="messageBody[id/]"><td width="5" align="left" style=" background-position:left;background-image:url('/style/[style/]/window/wlbg.png'); background-repeat:repeat-y;"></td><td align="left"  style=" background-image:url('/style/[style/]/window/background.png');padding-top:5px;">
[/windowheader]
[windowfooter]
</td><td width="5" align="left" style=" background-position:left;background-image:url('/style/[style/]/window/wrbg.png');background-repeat:repeat-y;"></td></tr><tr align="left"><td  width="5"><img src="/style/[style/]/window/wlubg.png" alt="" width="5" height="2" border="0"/></td><td style=" background-image:url('/style/[style/]/window/wdcubg.png'); background-repeat:repeat-x;"></td><td><img src="/style/[style/]/window/wrubg.png" alt="" width="5" height="2" border="0"/></td></tr>
</table>
<br/>
[/windowfooter]
