/*allgemein*/
body{
background-color:#ffffff;
font-family:verdana,sans-serif;
color:black;
text-align:left;
vertical-align:top;
font-size:20px;
}
a.catLink{
cursor:pointer;
color:black;
}
a.catLink:hover{
cursor:pointer;
color:blue;
}
a.catLinkPressed{
cursor:pointer;
color:red;
}
a.catLinkPressed:hover{
cursor:pointer;
color:red;
}
a{
cursor:pointer;
color:black;
white-space:nowrap;
}
a:hover{
cursor:pointer;
color:blue;
white-space:nowrap;
}
a.dropzone22{
color:#000;
cursor:pointer;
font-family:verdana,sans-serif;
font-size:14px;
height:22px;
vertical-align:top;
background-color:red;
}
a.link{
cursor:pointer;
color:black;
white-space:nowrap;
}
a.link:visited{
cursor:pointer;
color:#151b30;
white-space:nowrap;
}
a.link:hover{
cursor:pointer;
color:blue;
white-space:nowrap;
}
a.menuLink{
color:#396dcd;
font-size:18px;
vertical-align:middle;
}
a.menuLink:hover{
color:#396dce;
font-size:18px;
vertical-align:middle;
}
a.menuLink2{
color:#396dcd;
font-size:22px;
vertical-align:middle;
}
a.menuLink3{
color:black;
font-size:22px;
vertical-align:middle;
}
a.linkpressed{
color:#5299E6;
background-position:0%;
}
table.body{
width:100%;
}
table.blog{
background-color:#e6dede;
color:#000000;
}
td.content{
width:100%;
padding-left:0px;
padding-right:0px;
}
td.tabwidgetBody{
background-color:#888786;
padding-top:0px;
padding-left:10px;
padding-right:10px;
}
td.sidebar{
padding-right:0px;
}
td.leftSidebar{
padding-top:10px;
padding-left:5px;
padding-right:5px;
padding-bottom:10px
}
td.rightSidebar{
padding-top:8px;
padding-left:10px;
padding-right:10px;
}
table.contentLayout{
padding-top:10px;
padding-left:5px;
padding-right:0px;
}
table.contentHeader{
padding-top:2px;
padding-left:5px;
padding-right:5px;
}
table.reg{
width:250px;
}
/*<<allgemein*/
/* datenbank headline */
.sqlBox{width:80%;overflow:auto;}
.BaseN{color:#007f00}
.BString{color:#c9a7ff}
.Char{color:#ff00ff}
.Comment{color:#7f7f7f}
.DataType{color:#0000ff}
.DecVal{color:#00007f}
.Error{color:#ff0000}
.Float{color:#00007f}
.Function{color:#007f00}
.IString{color:#ff0000}
.Keyword{color:#0000ff}
.Normal{color:#000}
.Operator{color:#ffa500}
.Others{color:#b03060}
.RegionMarker{color:#96b9ff}
.Reserved{color:#9b30ff}
.String{color:#ff0000}
.Variable{color:#0000ff}
.Warning{color:#0000ff}
a.currentLink{
cursor:pointer;
color:red;
white-space:nowrap;
}
a.dropdown{
font-size:22px;
cursor:pointer;
background-color:#eee;
}
a.menupoint{
color:#000;
font-size:22px;
cursor:pointer;
}
a.menupoint:hover{
color:#f00;
font-size:22px;
cursor:pointer;
}
a.dropdown:hover{
background-color:#eef;
color:#000;
font-size:22px;
cursor:pointer;
}
a.pressed{
cursor:pointer;
font-size:22px;
color:#000;
background-color:#eee;
}
table.menupopup{
color:#000;
background-color:#eee;
border-style:solid;
border-width:1px;
border-left:1px;
border-bottom:0px;
border-top:1px;
border-right:1px;
font-size:22px;
}
input{
border:1px solid black;
color:black;
font-family:verdana,sans-serif;
vertical-align:top;
}
select{
vertical-align:top;
border:1px solid black;
color:black;
font-family:verdana,sans-serif;
}
textarea{
font-size:18px;
border:1px solid black;
color:black;
}
.markBox{
width:22px;
height:22px;
}
.markBoxButton{
width:22px;
height:22px;
}
tr.caption{
color:black;
background-color:#396dcd;
text-align:center;
}
tr.overDb{
color:black;
background-color:#d4d0c8;
}
td.overDb{
color:black;
background-color:#d4d0c8;
}
td.caption{
color:#ffffff;
background-color:#396dcd;
border-bottom:1px;
border-bottom-style:solid;
border-left-style:solid;
text-align:center;
}
