td.underL{
background-image:url('/style/lze/tabwidget/mlU.png');
background-repeat:no-repeat;
height:24px;
}
td.under{
background-image:url('/style/lze/tabwidget/mmU.png');
background-repeat:repeat-x;
height:24px;
}
td.underline{
background-image:url('/style/lze/tabwidget/str.jpg');
background-repeat:repeat-x;
background-position:bottom;
}
td.underR{
background-image:url('/style/lze/tabwidget/mrU.png');
background-repeat:no-repeat;
height:24px;
}
 td.over{
background-image:url('/style/lze/tabwidget/mmO.png');
height:25px;
background-repeat:repeat-x;
}
td.overL{
background-image:url('/style/lze/tabwidget/mlO.png');
background-repeat:no-repeat;
height:25px;
}
td.overR{
background-image:url('/style/lze/tabwidget/mrO.png');
background-repeat:no-repeat;
height:25px;
}
td.line{
background-image:url('/style/lze/tabwidget/mul.png');
}
/*td.tabwidgetBody{
background-color:#888786;
padding-left:5px;
padding-right:5px;
}*/
td.rechtsk{
background-image:url('/style/lze/tabwidget/str.jpg');
background-repeat:repeat-y;
background-position:right;
}
td.linksTab{
background-image:url('/style/lze/tabwidget/str.jpg');
background-repeat:repeat-y;
background-position:left;
}
td.hor{
background-image:url('/style/lze/tabwidget/str.jpg');
background-repeat:repeat-x;
background-position:bottom;
font-size:8px;
color:white;
font-family:sans-serif;
}
td.horRibbon{
background-image:url('/style/lze/tabwidget/str.jpg');
background-repeat:repeat-x;
background-position:bottom;
background-color:#888786;
}
td.bodyTab{
background-color:#888786;
}