table.blog{
background-color:#e6dede;
color:#000000;
}
span.Variable_Array{color:#840808}
span.Variable_Hash{color:#840808;}
span.Variable_Typeglob{color:#840808;}
span.Subroutine{color:black;}
span.Quote{color:blue;}
span.String{color:black;}
span.Comment_Normal{color:gray;}
span.Comment_POD{color:gray;}
span.Bareword{color:#3A3;}
span.Package{color:#900;}
span.Number{color:#f0f;}
span.Operator{color:#000;}
span.Symbol{color:#000;}
span.Character{color:#800;}
span.Directive{color:#399;font-style:italic;}
span.Label{color:#939;font-style:italic;}
span.Line{color:blue;}
a.Builtin_Operator{color:blue;}
a.Builtin_Function{color:blue;}
a.Keyword{color:blue;}
td.header{
text-align:left;
vertical-align:top;
background-color:#ffffff;
color:#000000;
font-size:18px;
 border-bottom-style:solid;
 border-top-style:solid;
}
td.short{
text-align:center;
vertical-align:top;
font-weight:bold;
border-right:gray;
border-right-style: dashed;
border-right-width:1px;
 border-bottom: gray;
 border-bottom-style:dashed;
border-bottom-width:1px;
}
td.middle{
text-align:center;
vertical-align:top;
font-weight:bold;
border-right:gray;
border-right-style: dashed;
border-right-width:1px;
border-bottom: gray;
border-bottom-style:dashed;
border-bottom-width:1px;
}
td.long{
text-align:left;
vertical-align:top;
border-bottom: gray;
border-bottom-style:dashed;
border-bottom-width:1px;
}
pre { color: #000000; 
      background: #FFFFFF;
      font-family: courier;
} 
.c  { color: gray;} /* comment */
.cm { color: #000000;} /* comma */
.co { color: #000000;} /* colon */
.h  { color: #000000; font-weight:bold;} /* here-doc-target */
.hh { color: #000000; font-style:italic;} /* here-doc-text */
.i  { color: blue;} /* identifier */
.j  { font-weight:bold;} /* label */
.k  {  font-weight:bold;} /* keyword */
.m  { color: blue; font-weight:bold;} /* subroutine */
.n  { color: #B452CD;} /* numeric */
.p  { color: #000000;} /* paren */
.pd { color: gray; font-style:italic;} /* pod-text */
.pu { color: #000000;} /* punctuation */
.q  { color: green;} /* quote */
.s  { color: #000000;} /* structure */
.sc { color: #000000;} /* semicolon */
.v  { color: #070C76;} /* v-string */
.w  { color: #070C76;} /* bareword */
