[windowheader]
<table align="center" border="0" cellpadding="0" cellspacing="0" summary=""  id="window[id/]" [hidden/] class="[class/]" >
<tr id="tr[id/]" [hidden/]  style="cursor:pointer">
<td>
<table align="left" border="0" cellpadding="0" cellspacing="0" summary="" width="100%">
<tr>
<td width="10" valign="top">
<table align="left" border="0" cellpadding="0" cellspacing="0" summary="" width="100%">
<tr>
<td><img src="/style/lze/window/linksObenK.png" class="lorkg" width="10" height="10" alt="" border="0"/></td>
<!--</tr>
<tr>
<td height="20" class="body"><table border="0" cellpadding="0" cellspacing="0" summary="" width="100%"><tr><td class="linksk"  height="20"></td></tr></table></td>-->
</tr>
</table>
</td>
<td class="body" >
<table  align="center" border="0" cellpadding="0" summary="" cellspacing="0"  width="100%">
<tr>
<td class="obenK" ></td>
<td width="2" height="10" class="rechtsk"><img src="/style/lze/window/str.jpg" width="2" height="2" border="0" alt=""/></td>
</tr>
</table>
</td>
</tr>
</table>
</td>
</tr>
<tr  id="messageBody[id/]">
<td class="body">
<table align="center" border="0" cellpadding="0" cellspacing="0" summary="" width="100%">
<tr>
<td width="2" class="linksk"><img src="/style/lze/window/str.jpg" width="2" height="2" border="0" alt=""/></td>
<td align="left" class="windowContent">
[/windowheader]
[windowfooter]
</td>
<td class="rechtsk" width="2"><img src="/style/lze/window/str.jpg" width="2" height="2" border="0" alt=""/></td>
</tr>
</table>
</td>
</tr>
<tr>
<td>
<table align="left" border="0" cellpadding="0" cellspacing="0" summary="" width="100%">
<tr>
<td class="body">
<table  align="center" border="0" cellpadding="0" summary="" cellspacing="0"  width="100%">
<tr>
<td width="2" height="10" class="linksk" align="left"><img src="/style/lze/window/str.jpg" width="2" height="2" border="0" alt=""/></td>
<td class="hor" height="2" valign="bottom"><img src="/style/lze/window/str.jpg" width="2" height="2" border="0" alt=""/></td>
</tr>
</table>
</td>
<td width="10" ><img src="/style/lze/window/rechtsUntenK.png" class="obrkg"  alt="" width="10" height="10" hspace="0" vspace="0" border="0"/></td>
</tr>
</table>
</td>
</tr>
</table>
[/windowfooter]