[header]
<table  border ="0" align="center" cellpadding ="2" cellspacing="2" summary="navigation" ><tr><td>[pages/]</td>
[/header]
[links]
<td><a class="menuLink3" href="[href/]">[title/]</a></td>
[/links]
[currentLinks]
<td><a class="menuLink2" href="[href/]">[title/]</a></td>
[/currentLinks]
[previous]
<td><a class="menuLink2" href="[href/]"><img src="/style/lze/prev.png" alt="Previous" border="0" title="Previous" style="cursor:pointer;"/></a></td>
[/previous]
[next]
<td><a class="menuLink2" href="[href/]"><img src="/style/lze/next.png" alt="Next" border="0" title="Next" style="cursor:pointer;"/></a></td>
[/next]
[footer]
</tr></table>
[/footer]
