a.treeviewLink22 {
color:#000;
cursor:pointer;
height:15px;
height:22px;
vertical-align:top;
white-space:nowrap;
}
a.dropzone22{
color:#000;
cursor:pointer;
font-family:verdana,sans-serif;
height:15px;
height:22px;
vertical-align:top;
background-color:red;
white-space:nowrap;
}
a.treeviewLink22:hover {
color:red;
cursor:pointer;
height:15px;
height:22px;
vertical-align:top;
white-space:nowrap;
}
table.treeview22 {
color:#000;
white-space:nowrap;
}
td.caption22 {
font-family:verdana, sans-serif;
height:15px;
height:22px;
white-space:nowrap;
}
td.captionBorder22 {
border-bottom:1px;
border-bottom-style:dashed;
color:#000;
font-family:verdana, sans-serif;
height:15px;
height:22px;
vertical-align:top;
white-space:nowrap;
}
td.columnsFolder22 {
font-family:verdana, sans-serif;
height:15px;
height:22px;
vertical-align:top;
white-space:nowrap;
}
td.columnsFolderBorder22,td.columnsNodeBorder22,td.columnsLastNodeBorder22 {
border-left:1px;
border-left-style:dashed;
color:#000;
font-family:verdana, sans-serif;
height:15px;
height:22px;
vertical-align:top;
white-space:nowrap;
}
td.columnsNode22,td.columnsLastNode22 {
font-family:verdana, sans-serif;
height:15px;
height:22px;
vertical-align:top;
white-space:nowrap;
}
td.folder22 {
background-image:url('/style/lze/22/html-menu-treeview/folderOpen.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
height:15px;
height:22px;
vertical-align:top;
white-space:nowrap;
}
td.folderClosed22 {
background-image:url('/style/lze/22/html-menu-treeview/folderClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
height:15px;
height:22px;
vertical-align:top;
white-space:nowrap;
}
td.lastMinusNode22 {
background-image:url('/style/lze/22/html-menu-treeview/lastMinusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
vertical-align:top;
white-space:nowrap;
}
td.lastNode22 {
background-image:url('/style/lze/22/html-menu-treeview/lastNode.gif');
background-repeat:no-repeat;
cursor:pointer;
height:15px;
height:22px;
vertical-align:top;
white-space:nowrap;
}
td.lastPlusNode22 {
background-image:url('/style/lze/22/html-menu-treeview/lastPlusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
height:22px;
vertical-align:top;
white-space:nowrap;
}
td.minusNode22 {
background-image:url('/style/lze/22/html-menu-treeview/minusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
vertical-align:top;
white-space:nowrap;
}
td.node22 {
background-image:url('/style/lze/22/html-menu-treeview/node.gif');
cursor:pointer;
height:15px;
height:22px;
white-space:nowrap;
}
td.plusNode22 {
background-image:url('/style/lze/22/html-menu-treeview/plusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
vertical-align:top;
white-space:nowrap;
}
td.submenuDeco22 {
background-image:url('/style/lze/22/html-menu-treeview/vertLine.gif');
background-repeat:repeat-y;
white-space:nowrap;
}